{% extends "django_sql_dashboard/widgets/_base_widget.html" %}

{% block widget_results %}
  {% for row in result.rows %}
    <div class="completed-count-total-count">
      <div class="completed-count-total-count-bar" style="width: {% widthratio row.completed_count row.total_count 100 %}%">&nbsp;</div>
    </div>
    <h2>{{ row.completed_count }} / {{ row.total_count }}: {% widthratio row.completed_count row.total_count 100 %}%</h2>
  {% endfor %}
{% endblock %}
