main {
  margin-top: 1em;
  font-family: Helvetica, sans-serif;
}
main img {
  height: 2em;
}
table {
  margin-top: 1em;
  border-collapse: collapse;
  border-spacing: 0;
}
th {
  white-space: nowrap;
  text-align: left;
  padding: 4px;
  padding-right: 1em;
  border-right: 1px solid #eee;
}
td {
  border-top: 1px solid #aaa;
  border-right: 1px solid #eee;
  padding: 4px;
  vertical-align: top;
  white-space: pre-wrap;
}
span.null {
  color: #aaa;
  font-weight: bold;
}
pre.json {
  margin: 0;
}
.btn {
  font-weight: 400;
  cursor: pointer;
  text-align: center;
  vertical-align: middle;
  border: 1px solid #666;
  padding: 0.5em 0.8em;
  font-size: 0.9rem;
  line-height: 1;
  border-radius: 0.25rem;
}
.query-results {
  border: 1px solid #666;
  border-right: none;
  margin: 1em 0;
  padding: 1em;
}
.query-results textarea,
.query-results pre.sql {
  width: 95%;
  border: 2px solid #666;
  padding: 0.5em;
}
.pre-results textarea {
  height: 4em;
}
div.query-parameters {
  width: 80%;
  display: grid;
  grid-template-columns: min-content auto;
  grid-gap: 0.5em;
  align-items: center;
  margin-bottom: 1em;
}
div.query-parameters input[type="text"] {
  border: 1px solid #666;
  padding: 0.5em;
}
div.query-parameters label {
  text-align: right;
  font-weight: bold;
  display: inline-block;
  padding-right: 2em;
}
.completed-count-total-count {
  width: 60%;
  background-color: #efefef;
  height: 3em;
}
.completed-count-total-count-bar {
  background-color: blue;
  height: 3em;
}

.save-dashboard-form p {
  width: 80%;
}
.save-dashboard-form label {
  text-align: left;
  font-weight: bold;
  display: inline-block;
  width: 20%;
}
.save-dashboard-form input {
  border: 1px solid #666;
  padding: 0.5em;
}
.save-dashboard-form .errorlist {
  color: red;
}
.save-dashboard-form .helptext {
  color: #666;
  white-space: nowrap;
}
ul.dashboard-columns {
  column-count: 2;
}
ul.dashboard-columns li {
  break-inside: avoid;
  margin-bottom: 0.3em;
}
ul.dashboard-columns li p {
  margin: 0;
  color: #666;
  font-size: 0.8em;
}
@media (max-width: 800px) {
  ul.dashboard-columns {
    column-count: auto;
  }
}
